@@ -6,7 +6,7 @@
     Allow `KaTeX <khan.github.io/KaTeX/>`_ to be used to display math in
     Sphinx's HTML writer.
 
-    :copyright: Copyright 2017-2020 by Hagen Wierstorf.
+    :copyright: Copyright 2017-2021 by Hagen Wierstorf.
     :license: MIT, see LICENSE for details.
 """
 
@@ -24,8 +24,8 @@ from sphinx.errors import ExtensionError
 from sphinx.util.osutil import copyfile
 
 
-__version__ = '0.7.2'
-katex_version = '0.12.0'
+__version__ = '0.8.4'
+katex_version = '0.13.11'
 filename_css = 'katex-math.css'
 filename_autorenderer = 'katex_autorenderer.js'
 
@@ -85,9 +85,13 @@ def run_katex(latex, *options):
         (cmd, ) + options,
         stdout=subprocess.PIPE,
         stdin=subprocess.PIPE,
+        stderr=subprocess.PIPE,
         env=os.environ.copy()
     )
     stdout, stderr = p.communicate(latex.encode('utf-8'))
+    if p.returncode:
+        msg = 'KaTeX failed with\n: ' + stderr.decode('utf-8')
+        raise RuntimeError(msg)
     return stdout.decode('utf-8')
 
 
@@ -135,10 +139,13 @@ def builder_inited(app):
     if not (app.config.katex_js_path and app.config.katex_css_path and
             app.config.katex_autorender_path):
         raise ExtensionError('KaTeX paths not set')
-    # Sphinx 1.8 renamed `add_stylesheet` to `add_css_file` and
-    # `add_javascript` to `add_js_file`.
-    add_css = getattr(app, 'add_css_file', getattr(app, 'add_stylesheet'))
-    add_js = getattr(app, 'add_js_file', getattr(app, 'add_javascript'))
+    # Sphinx 1.8 renamed `add_stylesheet` to `add_css_file`
+    # and `add_javascript` to `add_js_file`.
+    # Sphinx 4.0 finally removed `add_stylesheet` and `add_javascript`.
+    old_css_add = getattr(app, 'add_stylesheet', None)
+    old_js_add = getattr(app, 'add_javascript', None)
+    add_css = getattr(app, 'add_css_file', old_css_add)
+    add_js = getattr(app, 'add_js_file', old_js_add)
     add_css(app.config.katex_css_path)
     # Ensure the static path is setup to hold KaTeX CSS and autorender files
     setup_static_path(app)
